import request from '@/utils/request'

// 查询积分商品列表
export function listWares(query) {
  return request({
    url: '/integral/wares/list',
    method: 'get',
    params: query
  })
}

// 查询积分商品详细
export function getWares(id) {
  return request({
    url: '/integral/wares/' + id,
    method: 'get'
  })
}

// 新增积分商品
export function addWares(data) {
  return request({
    url: '/integral/wares',
    method: 'post',
    data: data
  })
}

// 修改积分商品
export function updateWares(data) {
  return request({
    url: '/integral/wares',
    method: 'put',
    data: data
  })
}

// 修改
export function editInfoWares(data) {
  return request({
    url: '/integral/wares/editInfoWares',
    method: 'post',
    data: data
  })
}

// 删除积分商品
export function delWares(id) {
  return request({
    url: '/integral/wares/' + id,
    method: 'delete'
  })
}

// 导出积分商品
export function exportWares(query) {
  return request({
    url: '/integral/wares/export',
    method: 'get',
    params: query
  })
}